@@ -1,4 +1,4 @@
-# Copyright (C) 2008, Sebastian Riedel.
+# Copyright (C) 2008-2009, Sebastian Riedel.
 
 package Mojo::Filter::Chunked;
 
@@ -32,7 +32,7 @@ sub build {
         $formatted = "\x0d\x0a0\x0d\x0a";
 
         # Trailing headers
-        $formatted .= "$chunk\x0d\x0a\x0d\x0a" if $headers;
+        $formatted .= $headers ? "$chunk\x0d\x0a\x0d\x0a" : "\x0d\x0a";
     }
 
     # Separator
@@ -53,10 +53,10 @@ sub parse {
     my $self = shift;
 
     # Trailing headers
-   if ($self->is_state('trailing_headers')) {
-       $self->_parse_trailing_headers;
-       return $self;
-   }
+    if ($self->is_state('trailing_headers')) {
+        $self->_parse_trailing_headers;
+        return $self;
+    }
 
     # Got a chunk (we ignore the chunk extension)
     my $filter = $self->input_buffer;
@@ -66,18 +66,7 @@ sub parse {
         # Last chunk
         if ($length == 0) {
             $filter->{buffer} =~ s/^$1//;
-
-            # Trailing headers
-            if ($self->headers->trailer) {
-                $self->state('trailing_headers');
-            }
-
-            # Done
-            else {
-                $self->_remove_chunked_encoding;
-                $filter->empty;
-                $self->done;
-            }
+            $self->state('trailing_headers');
             last;
         }
 
@@ -94,7 +83,7 @@ sub parse {
             }
 
             # Not a whole chunk, need to wait for more data
-            else { last }
+            else {last}
         }
     }
 
@@ -113,10 +102,13 @@ sub _parse_trailing_headers {
 }
 
 sub _remove_chunked_encoding {
-    my $self = shift;
+    my $self     = shift;
     my $encoding = $self->headers->transfer_encoding;
     $encoding =~ s/,?\s*chunked//ig;
-    $self->headers->transfer_encoding($encoding);
+    $encoding
+      ? $self->headers->transfer_encoding($encoding)
+      : $self->headers->remove('Transfer-Encoding');
+    $self->headers->content_length($self->output_buffer->raw_length);
 }
 
 1;
@@ -163,4 +155,4 @@ implements the following new ones.
 
     $filter = $filter->parse;
 
-=cut
\ No newline at end of file
+=cut
