@@ -95,7 +95,7 @@ sub cookies {
     return [];
 }
 
-sub default_message { return $MESSAGES{$_[1] || $_[0]->code || 200} }
+sub default_message { $MESSAGES{$_[1] || $_[0]->code || 200} }
 
 sub fix_headers {
     my $self = shift;
