@@ -1,4 +1,4 @@
-# Copyright (C) 2008, Sebastian Riedel.
+# Copyright (C) 2008-2009, Sebastian Riedel.
 
 package Mojo::Server;
 
@@ -12,49 +12,59 @@ use Mojo::Loader;
 
 use constant RELOAD => $ENV{MOJO_RELOAD} || 0;
 
-__PACKAGE__->attr('app',
-    chained => 1,
-    default => sub { Mojo::Loader->load_build(shift->app_class) }
-);
-__PACKAGE__->attr('app_class',
-    chained => 1,
-    default => sub { $ENV{MOJO_APP} ||= 'Mojo::HelloWorld' }
-);
-__PACKAGE__->attr('build_tx_cb',
-    chained => 1,
-    default => sub {
-        return sub {
-            my $self = shift;
-
-            # Reload
-            if (RELOAD) {
-                Mojo::Loader->reload;
-                delete $self->{app};
-            }
-
-            return $self->app->build_tx;
+__PACKAGE__->attr(
+    app => (
+        default => sub {
+            my $e = Mojo::Loader->load_build(shift->app_class);
+            die $e if ref $e eq 'Mojo::Loader::Exception';
+            return $e;
         }
-    }
+    )
 );
-__PACKAGE__->attr('continue_handler_cb',
-    chained => 1,
-    default => sub {
-        return sub {
-            my ($self, $tx) = @_;
-            $tx->res->code(100);
-            return $tx;
-        };
-    }
+__PACKAGE__->attr(
+    app_class => (default => sub { $ENV{MOJO_APP} ||= 'Mojo::HelloWorld' }));
+__PACKAGE__->attr(
+    build_tx_cb => (
+        default => sub {
+            return sub {
+                my $self = shift;
+
+                # Reload
+                if (RELOAD) {
+                    my $e = Mojo::Loader->reload;
+                    warn $e if $e;
+                    delete $self->{app};
+                }
+
+                return $self->app->build_tx;
+              }
+        }
+    )
 );
-__PACKAGE__->attr('handler_cb',
-    chained => 1,
-    default => sub {
-        return sub {
-            my ($self, $tx) = @_;
-            $self->app->handler($tx);
-            return $tx;
-        };
-    }
+__PACKAGE__->attr(
+    continue_handler_cb => (
+        default => sub {
+            return sub {
+                my ($self, $tx) = @_;
+                if ($self->app->can('continue_handler')) {
+                    $self->app->continue_handler($tx);
+                }
+                else { $tx->res->code(100) }
+                return $tx;
+            };
+        }
+    )
+);
+__PACKAGE__->attr(
+    handler_cb => (
+        default => sub {
+            return sub {
+                my ($self, $tx) = @_;
+                $self->app->handler($tx);
+                return $tx;
+            };
+        }
+    )
 );
 
 # It's up to the subclass to decide where log messages go
@@ -173,4 +183,4 @@ L<Mojo::Server::Daemon::Prefork> - Preforking standalone HTTP server.
 
 L<Mojo::Server::FastCGI> - A FastCGI server.
 
-=cut
\ No newline at end of file
+=cut
